@@ -1,3 +1,5 @@
+use utf8;
+use warnings;
 no warnings 'redefine';
 use vars qw($hrUser $contakt $puplisher);
 $hrUser    = $m_oDatabase->fetch_hashref("select * from  users where user = 'admin'");
@@ -14,3 +16,4 @@ $hrUser->{firstname} $hrUser->{name}<br/>
 $hrUser->{email}<br/>
 $hrUser->{phone}<br/></div>
 |;
+1;
\ No newline at end of file
