@@ -1,3 +1,6 @@
+use utf8;
+# use strict;
+use warnings;
 no warnings 'redefine';
 use vars qw( $m_sAkt $m_nLength $m_nReplyId );
 
@@ -115,9 +118,6 @@ sub saveedit {
         my $headline = param('headline');
         $headline = ($headline =~ /^(.{3,50})$/) ? $1 : 0;
         my $body = param('message');
-
-        #         my $max = $m_hrSettings->{news}{maxlength} < 32766 ? $m_hrSettings->{news}{maxlength} : 0;
-        #         $body = ($body =~ /^(.{3,$max})$/s) ? $1 : translate('invalidBody') if $max > 0;
         &saveUpload() if $m_nRight >= $m_hrSettings->{uploads}{right};
         my $attach = (param('file')) ? (split(/[\\\/]/, param('file')))[-1] : 0;
         my $cit  = (defined $attach) ? $attach =~ /^(\S+)\.[^\.]+$/ ? $1 : 0 : 0;
@@ -184,7 +184,7 @@ sub editNews {
             headline => $data[0],
             title    => translate('editMessage'),
             right    => $m_nRight,
-            catlist  => ($th eq 'news') ? $catlist : ' ',
+            catlist  => ($th eq 'news') ? $catlist : ' ',
             html     => $html,
             atemp =>
               qq(<input  name="von" value="$m_nStart" style="display:none;"/><input  name="bis" value="$m_nEnd" style="display:none;"/>),
@@ -351,15 +351,10 @@ sub showMessage {
     my $sql_read =
       qq/select title,body,date,id,user,attach,format from  news where `id` = $id && `right` <= $m_nRight && cat REGEXP($qcats)/;
     my $ref = $m_oDatabase->fetch_hashref($sql_read);
-
-    #     foreach my $key ( keys %$ref ){
-    #       unless ( utf8::is_utf8(  $ref->{$key} ) and  $key eq 'title'){
-    # 	  utf8::decode(  $ref->{$key}  );
-    #       }
-    #     }
     if ($ref->{id} eq $id) {
         my $m_sTitle = $ref->{title};
         $ref->{body} =~ s/\[previewende\]//s;
+        
         if ($ACCEPT_LANGUAGE eq 'de') {
             $ref->{body} =~ s/\[en\](.*?)\[\/en\]//gs;
             $ref->{body} =~ s/\[de\](.*?)\[\/de\]/$1/gs;
@@ -368,6 +363,7 @@ sub showMessage {
             $ref->{body} =~ s/\[de\](.*?)\[\/de\]//gs;
         }
         if ($ref->{format} eq 'bbcode') {
+
             BBCODE(\$ref->{body});
         } else {
             $ref->{body} =~
@@ -409,8 +405,10 @@ sub showMessage {
                       style    => $m_sStyle,
                      );
         $menu .= action(\%delete) if ($m_nRight >= 5);
+
+
         print br()
-          . qq(<table class="ShowTables"><tr><td class="headline">$ref->{title}</td></tr><tr><td align="left" class="batch">$menu</td></tr><tr><td align="left"><table align="left" border ="0" cellpadding="0" cellspacing="0" summary="user_date" width="100%"><tr><td align="left" class="username">$ref->{user}</td><td align="right" class="date">$ref->{date}</td></tr></table></td></tr><tr><td align="left"> $ref->{body} </td></tr>);
+          . qq(<table class="ShowTables"><tr><td class="headline">$ref->{title}</td></tr><tr><td align="left" class="batch">$menu</td></tr><tr><td align="left"><table align="left" border ="0" cellpadding="0" cellspacing="0" summary="user_date" width="100%"><tr><td align="left" class="username">$ref->{user}</td><td align="right" class="date">$ref->{date}</td></tr></table></td></tr><tr><td align="left">$ref->{body}</td></tr>);
         print
           qq(<tr><td><a target="_blank" href="download/$ref->{attach}">$ref->{attach}</a></td></tr>)
           if (-e "$m_hrSettings->{uploads}{path}/$ref->{attach}");
@@ -472,7 +470,7 @@ sub preview {
     print '<br/>';
     my $html = defined param('format') ? param('format') : 'off';
     $html = $html eq 'on' ? 1 : 0;
-    utf8::decode($body) unless (utf8::is_utf8($body));
+#     utf8::decode($body) unless (utf8::is_utf8($body));
     unless ($html) {
         BBCODE(\$body);
     } else {
@@ -561,7 +559,7 @@ sub showThread {
         td(
             div(
                 {align => 'right'},
-                ($m_nLength > 5 ? translate('news_pro_page') . ' | ' : '')
+                ($m_nLength > 5 ? translate('news_pro_page') . ' | ' : '')
                   . (
                     $m_nLength > 5
                     ? a(
@@ -708,9 +706,9 @@ sub threadBody {
             $menu .= action(\%delete) if ($m_nRight >= 5);
             my $h1       = qq(<tr id="trw$id"><td valign="top">);
             my $readmore = translate('readmore');
-            $reply .= qq( <a href="$replylink" class="link" >$readmore</a>)
+            $reply .= qq( <a href="$replylink" class="link" >$readmore</a>)
               if $body =~ /\[previewende\]/i && $thread eq 'news';
-
+# 	    utf8::decode($body) unless utf8::is_utf8($body);
             if ($th eq 'news') {
                 if ($ACCEPT_LANGUAGE eq 'de') {
                     $body =~ s/\[en\](.*?)\[\/en\]//gs;
@@ -797,7 +795,7 @@ sub trash {
                 <td align="center">$trash[$i]->{oldId}</td>
                 <td align="center">$trash[$i]->{refererId}</td>
                 <td align="center">$trash[$i]->{cat}</td>
-                <td align="right" style="padding-right:1%;"><a href="javascript:requestURI('$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}?action=rebuildtrash&id=$trash[$i]->{id}','news','news')" width="50">$rebuild</a> <a href="javascript:requestURI('$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}?action=DeleteEntry&table=trash&&id=$trash[$i]->{id}','news','$m_sTitle');">$delete</a></td>
+                <td align="right" style="padding-right:1%;"><a href="javascript:requestURI('$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}?action=rebuildtrash&id=$trash[$i]->{id}','news','news')" width="50">$rebuild</a> <a href="javascript:requestURI('$m_hrSettings->{cgi}{serverName}$ENV{SCRIPT_NAME}?action=DeleteEntry&table=trash&&id=$trash[$i]->{id}','news','$m_sTitle');">$delete</a></td>
                 </tr>);
     }
     my $delete   = translate('delete');
