@@ -1,9 +1,12 @@
-my $sTitle  = translate('userprofile');
-my $hrUser  = $m_oDatabase->fetch_hashref("select * from  users where user = '$m_sUser'");
-my @aSelect = split /\|/, $hrUser->{cats};
-my (%hSel, @catz);
+use utf8;
+use warnings;
+no warnings 'redefine';
+use vars qw($sTitle $hrUser @aSelect %hSel @catz @aCats);
+$sTitle  = translate('userprofile');
+$hrUser  = $m_oDatabase->fetch_hashref("select * from  users where user = '$m_sUser'");
+@aSelect = split /\|/, $hrUser->{cats};
 $hSel{$_} = 1 foreach @aSelect;
-my @aCats = $m_oDatabase->fetch_AoH("select * from cats where `right` <= ?", $m_nRight);
+@aCats = $m_oDatabase->fetch_AoH("select * from cats where `right` <= ?", $m_nRight);
 
 for (my $i = 0 ; $i <= $#aCats ; $i++) {
     push @catz,
@@ -129,7 +132,8 @@ sub on_valid_form {
     my $pwChanged = 0;
     my $list;
 
-    for (my $i = 0 ; $i <= $#aCats ; $i++) {
+    for (my $i = 0 ; $i <= $#aCats ; $i++)
+    {
         $list .= '|' unless $i == 0;
         $list .= $aCats[$i]->{name} if (param($aCats[$i]->{name}) eq 'on');
     }
