@@ -1,3 +1,181 @@
+/*
+=head2 NAME
+
+    MySQL::Admin 
+
+=head2 SYNOPSIS
+
+    MySQL administration Web-App and Content Management System
+
+    cpan MySQL::Admin
+
+This System works like following: index.html 
+
+Css Overview:
+
+=begin html
+
+<pre>
+#############################################
+#  .window                                  #
+#  #######################################  #
+#  #.tab                                 #  #   
+#  #######################################  #
+#  #.menu                  #.content     #  #
+#  # ##################### #             #  # 
+#  # #.menuContainer     # #             #  #
+#  # #.verticalMenuLayout# #.ShowTables  #  #
+#  # #.menuCaption       # #.caption     #  #
+#  # #.menuContent       # #             #  #
+#  # ##################### #             #  #
+#  #                       #             #  #
+#  #######################################  #
+#                                           #
+#############################################
+</pre>
+
+=end html
+
+javascript/cms.js
+    
+      // In the  function init() a ( xmlhttprequest ) load the Content.
+      // <a onclick="requestURI('$ENV{SCRIPT_NAME}?action=HelloWorld','HelloWorld','HelloWorld')">HelloWorld</a>      
+
+=begin html
+
+<pre>
+      requestURI(
+        url,     // Script url  
+        id,      // Tabwidget id
+        txt,     // Tabwidget text
+        bHistory,// Browser History
+        formData,// Form Data 
+        method,  // Submit Type GET or POST
+       );
+    or 
+    <form onsubmit="submitForm(this,'$m_sAction','$m_sTitle');return false;" method="GET" enctype="multipart/form-data">
+    <input type="hidden" name="action" value="">
+</pre>
+
+=end html
+
+    since apache 2.x GET have maxrequestline so use POST for alarge requests.
+    
+    POST requests don't saved in the Browser history (back button ). 
+    
+install.sql
+
+    The actions will bill stored in actions.
+
+=begin html
+
+<pre>
+    INSERT INTO actions (
+        `action`, #Name of the action
+        `file`,   #file contain the code
+        `title`,  #title 
+        `right`,  #right 0 guest 1 user 5 admin
+        `sub`     # sub name  main for the while file 
+        ) values('HelloWorld','HelloWorld.pl','HelloWorld','0','main');
+
+    INSERT INTO actions (`action`,`file`,`title`,`right`,`sub`) values('HelloSub','HelloSub.pl','HelloWorld','0','HelloSub');
+</pre>
+
+=end html
+
+    In action_set:
+
+=begin html
+
+<pre>
+    INSERT INTO actions_set (
+        `action`,           #action called
+        `foreign_action`,   #foreign key
+        `output_id`         #output id 
+        ) values('HelloWorld','HelloWorld','content');
+
+    INSERT INTO actions_set (`action`,`foreign_action`,`output_id`) values('HelloWorld','HelloSub','otherOutput');
+    
+    
+    INSERT INTO mainMenu (
+        `title`,   # link title
+        `action`,  # action defined in actions_set
+        `right`,   # 0 guest 1 user 5 admin
+        `position`,# top 1 ... x bottom 
+        `menu`,    #top or left
+        `output`   #requestURI or javascript or loadPage  or href
+        )  values('HelloWorld','HelloWorld','0','1','top','requestURI');
+</pre>
+
+=end html
+
+  This will call 2 files HelloWorld.pl HelloSub.pl with following output.
+
+cgi-bin/Content/HelloWorld.pl
+
+    #Files are called via do ().
+    
+    #you are in the MySQL::Admin::GUI namespace
+
+    print  "Hello World !"
+    
+    .br()
+    
+    .a(
+    
+      {
+      
+      -href => "mailto:$m_hrSettings->{admin}{email}"
+      
+      },'Mail me')
+    
+    .br()
+    
+    1;
+
+cgi-bin/Content/HelloSub.pl
+
+    sub HelloSub{
+
+      print "sub called";
+    
+    }
+    
+    1;
+
+
+cgi-bin/mysql.pl
+
+    Returns a actionset stored in the Mysql Database.
+    
+    One sub for every output id.
+    
+    <xml>
+    
+    <output id="otherOutput">sub called</output>
+
+    <output id="content">Hello World !<br /><a href="mailto:">Mail me</a><br /></output>
+
+    </xml>
+
+this file will be transformed trough xslt in main Template     
+
+index.html
+
+    <div id=otherOutput>sub called</div>
+
+    <div id=content>Hello World !<br /><a href="mailto:">Mail me</a><br /></div>
+
+</pre>
+
+Under mod_perl the whole page load in 0.1 seconds.
+
+I write a whole Documentation soon.No feedback so I'm not in rush.
+
+Look at http://lindnerei.sourceforge.net or http://lindnerei.de further Details.
+ 
+*/
+
 style = "mysql";
 size = 16;
 right = 0;
@@ -7,6 +185,24 @@ maxLength = 1000;
 m_sid = '123';
 m_txt = '';
 
+/*
+
+=head2 loadPage(inXml, inXsl, outId, tabId, title)
+
+param inXml
+
+  XmL Document or filename
+
+param inXsl
+
+  XsL Document or filename
+  
+outId, tabId, title set L<requestURI>
+  
+=cut
+
+*/
+
 function loadPage(inXml, inXsl, outId, tabId, title) {
     xml = typeof inXml == 'object' ? inXml : loadXMLDoc(inXml);
     xsl = typeof inXsl == 'object' ? inXsl : loadXMLDoc(inXsl);
@@ -26,6 +222,18 @@ function loadPage(inXml, inXsl, outId, tabId, title) {
     if (outId == 'content') disableOutputEscaping('content');
 }
 
+/*
+
+=head2 intputMask(id, regexp) 
+
+ onkeydown="intputMask(this.id,"(\w+)")"
+ 
+ Would only accept chars for given id as Input.
+  
+=cut
+
+*/
+
 function intputMask(id, regexp) {
     var rxObj = regexp;
     rxObj.exec($(id).value);
@@ -89,6 +297,31 @@ function setCurrentTab(id, title) {
 var currentId, currentTxt;
 var act = 'save';
 
+//requestURI('cgi-bin/mysql.pl?action=loadSidebar',action,action,false,false,'GET',false)
+/*
+=head2 submitForm(node, tabId, tabTitle, bHistory, method, uri)
+
+=begin html
+
+<pre>
+      requestURI(
+        node,       // Script url  
+        tabId,      // Tabwidget id
+        tabTitle,   // Tabwidget text
+        bHistory,   // Browser History
+        method,     // Form Data 
+        uri,        // Submit Type GET or POST
+       );
+    or 
+    <form onsubmit="submitForm(this,'$m_sAction','$m_sTitle');return false;" method="GET" enctype="multipart/form-data">
+    <input type="hidden" name="action" value="">
+</pre>
+
+=end html
+
+=cut
+*/
+
 function submitForm(node, tabId, tabTitle, bHistory, method, uri) {
     bHistory = typeof bHistory !== 'undefined' ? bHistory : true;
     method = typeof method !== 'undefined' ? method : 'POST';
@@ -127,7 +360,33 @@ function submitForm(node, tabId, tabTitle, bHistory, method, uri) {
 }
 var http_request = false;
 var oldpage = 0;
+
+
 //requestURI('cgi-bin/mysql.pl?action=loadSidebar',action,action,false,false,'GET',false)
+/*
+=head2 requestURI(url, id, txt, bHistory, formData, method, bWaid)
+
+=begin html
+
+<pre>
+      requestURI(
+        url,     // Script url  
+        id,      // Tabwidget id
+        txt,     // Tabwidget text
+        bHistory,// Browser History
+        formData,// Form Data 
+        method,  // Submit Type GET or POST
+       );
+    or 
+    <form onsubmit="submitForm(this,'$m_sAction','$m_sTitle');return false;" method="GET" enctype="multipart/form-data">
+    <input type="hidden" name="action" value="">
+</pre>
+
+=end html
+
+=cut
+*/
+
 function requestURI(url, id, txt, bHistory, formData, method, bWaid) {
     setAction(id);
     closePopup();
@@ -169,6 +428,14 @@ function requestURI(url, id, txt, bHistory, formData, method, bWaid) {
     }
 }
 
+/*
+=head2 loadXMLDoc(filename)
+
+var xml = loadXMLDoc(filename);
+
+=cut
+*/
+
 function loadXMLDoc(filename) {
     if (window.ActiveXObject) {
         xhttp = new ActiveXObject("Msxml2.XMLHTTP");
@@ -219,6 +486,14 @@ function setContent() {
     }
 }
 
+/*
+=head2 alert(txt)
+
+Styled replacment for alert
+
+=cut
+*/
+
 function alert(txt) {
     visible('popup');
     setText('popupContent', '<div align="center">' + txt + '<br/><input  type="submit" id="confirmButton" value="Ok"/></div>');
@@ -233,6 +508,22 @@ function logError(message, file, line) {
     console.log("Message: " + message + "file: " + file + "line: " + line);
 }
 
+/*
+=head2 confirm2(txt, sub, arg, arg2, arg3) 
+
+Styled replacment for confirm.
+
+confirm2( 'Foo ?',
+    function(a,b){
+      alert (a +" " +b);
+     },
+     "foo",
+     "bar"
+     );"
+
+=cut
+*/
+
 function confirm2(txt, sub, arg, arg2, arg3) {
     visible('popup');
     setText('popupContent', '<b>' + txt +
@@ -280,6 +571,20 @@ function stopDrop() {
     m_bNoDrop = false;
 }
 
+/*
+=head2 prompt(txt, sub)
+
+Styled replacment for prompt.
+
+prompt('Enter Text',
+function(txt){
+ alert(txt);
+}
+);
+
+=cut
+*/
+
 function prompt(txt, sub) {
     visible('popup');
     setText('popupContent', '<b>' + txt +'</b><br/><input  type="text" align="center" id="promptPopUp"/><br/><div align="right" style="padding:0.4em;"><input type="submit" name="cancelButton" id="cancelButton" value="Cancel"/>&#160;<input  type="submit" id="confirmButton" value="Ok"/></div>');
@@ -331,6 +636,14 @@ function errorMessage(text) {
     location.href = "install.html";
 }
 
+/*
+=head2 evalId(id)
+
+eval <script></script> tags within given id
+
+=cut
+*/
+
 function evalId(id) {
     var content = $(id);
     if (content) {
@@ -341,8 +654,17 @@ function evalId(id) {
     }
 }
 
+/*
+=head2 translate(string)
+
+use MySQL::Admin for translations.
+
+=cut
+*/
+
 function translate(string) {
     var lng = navigator.language.indexOf("de") > -1 ? 'de' : 'en';
+    string.replace(/\s/g, '');
     if (typeof Lang != 'undefined') {
         var l = new Lang();
         if (string) {
@@ -372,19 +694,43 @@ function traversTranslate(id, lng, l) {
     }
 }
 
+/*
+
+=head2 disableOutputEscaping(id) 
+
+
+=cut
+
+*/
+
 function disableOutputEscaping(id) {
     if (navigator.userAgent.indexOf("Firefox") != -1) $(id).innerHTML = $(id).textContent;
 }
-//cms
+
+/*
+=head2 $(id) 
+
+ eq document.getElementById()
+
+=cut
+*/
+
 function $(id) {
     return document.getElementById(id);
 }
 
+/*
+=head2  insertAtCursorPosition(txt)
+
+
+=cut
+*/
+
 function insertAtCursorPosition(txt) {
     var textarea = $('sqlEdit');
     if (typeof document.selection != 'undefined') {
         range = document.selection.createRange();
-//         var txt = range.text;
+        var txt = range.text;
         range.text = txt;
         range.moveStart('character', txt.length);
         range.select();
@@ -397,8 +743,8 @@ function insertAtCursorPosition(txt) {
         textarea.value += txt;
     }
 }
-var nCurrentRow = 0;
 
+var nCurrentRow = 0;
 function enter(event) {
     var keyCode = event.keyCode ? event.keyCode : event.charCode ? event.charCode : event.which;
     if (keyCode == 13) return true;
@@ -440,7 +786,15 @@ function addEntry(idSelect, idEdit) {
     $(idSelect).options[n] = newEntry;
     $(idSelect).options[n].className = 'set';
 }
-// object.x - .y =  getElementPosition(id);
+
+/*
+=head2 getElementPosition(id) 
+
+ object.x - .y =  getElementPosition(id);
+
+=cut
+*/
+
 function getElementPosition(id) {
     var node = $(id);
     var offsetLeft = 0;
@@ -456,6 +810,13 @@ function getElementPosition(id) {
     return position;
 }
 
+/*
+=head2 move(id, x, y)
+
+
+=cut
+*/
+
 function move(id, x, y) {
     Element = $(id);
     Element.style.position = "absolute";
@@ -477,6 +838,14 @@ function showMenu(linkId, menuId) {
     displayTree(menuId);
 }
 
+/*
+=head2 getWindowSize()
+
+ object.x - .y =  getWindowSize();
+
+=cut
+*/
+
 function getWindowSize() {
     var nWidth = 0,
         nHeight = 0;
@@ -959,25 +1328,60 @@ function datum() {
     return d;
 }
 
+/*
+=head2 setText(id, string)
+
+
+=cut
+*/
+
 function setText(id, string) {
     var element = $(id);
     if (element) element.innerHTML = string;
     else window.status = id + string;
 }
 
+/*
+=head2 getText(id) 
+
+
+=cut
+*/
+
 function getText(id) {
     var element = $(id);
     if (element) return element.innerHTML;
 }
 
+/*
+=head2 hide(id) 
+
+
+=cut
+*/
+
 function hide(id) {
     if ($(id)) $(id).style.display = "none";
 }
 
+/*
+=head2 visible(id) 
+
+
+=cut
+*/
+
 function visible(id) {
     if ($(id)) $(id).style.display = "";
 }
-//API>>
+
+/*
+=head2 ScrolBarWidth()
+
+
+=cut
+*/
+
 function ScrolBarWidth() {
     //2 verschachtelte divs erzeugen.
     var ouside = document.createElement('div'); //aussen
@@ -1030,6 +1434,13 @@ function prepareMove(id) {
     startdrag(id);
 }
 
+/*
+=head2 enableDropZone(id)
+
+
+=cut
+*/
+
 function enableDropZone(id) {
     if (!dragobjekt) return;
     dropzone = id;
@@ -1060,7 +1471,6 @@ var dbAction = 'ShowTable';
 function setDbAction(n) {
     dbAction = n;
 }
-
 function showCatList() {
     var o = getElementPosition('catLink');       
     move('catlist', o.x, o.y+24);
@@ -1080,6 +1490,8 @@ function showTab(id) {
         }
     }
 }
+
+
 window.onpopstate = loadHistory;
 
 function loadHistory() {
@@ -1160,26 +1572,45 @@ function breakOut() {
     }
 }
 
+/*
+=head2 Autocomplete(evt)
+
+
+oAutocomplete = $("txt");
+
+autocomplete.push("foo");
+
+autocomplete.push("bar");
+
+oAutocomplete.addEventListener('keyup', Autocomplete);
+
+Autocomplete(evt) 
+
+<textarea id="txt"></textarea>
+
+=cut
+*/
+
 function Autocomplete(evt) {
     if (breakOut()) return;
     if (evt.which == 8 || evt.which == 16 || evt.which === 37 || evt.which === 38 || evt.which === 39 || evt.which === 39 || evt.which === 40) return;
     var offset = 3;
-    while ($("sqlEdit").selectionStart - offset >= 0 && offset < 10) { //todo port to IE
+    while (oAutocomplete.selectionStart - offset >= 0 && offset < 10) { //todo port to IE
         var match = ''
-        if ($("sqlEdit").value.substr($("sqlEdit").selectionStart - offset - 1, 1) == ' ' || $("sqlEdit").value.substr($("sqlEdit").selectionStart - offset - 1,
-                1).search(new RegExp("\\b")) == -1 || $("sqlEdit").selectionStart - offset == 0) {
-            match = $("sqlEdit").value.substr($("sqlEdit").selectionStart - offset, offset);
+        if (oAutocomplete.value.substr(oAutocomplete.selectionStart - offset - 1, 1) == ' ' || oAutocomplete.value.substr(oAutocomplete.selectionStart - offset - 1,
+                1).search(new RegExp("\\b")) == -1 || oAutocomplete.selectionStart - offset == 0) {
+            match = oAutocomplete.value.substr(oAutocomplete.selectionStart - offset, offset);
         }
         var i = 0;
         var j = autocomplete.length;
         while (i < autocomplete.length) {
             if (match == autocomplete[i].substr(0, offset)) {
-                var selectionStart = $("sqlEdit").selectionStart;
-                var before = $("sqlEdit").value.substr(0, selectionStart - offset);
-                var behind = $("sqlEdit").value.substr(selectionStart, $("sqlEdit").value.length);
-                $("sqlEdit").value = before + autocomplete[i] + behind;
-                $("sqlEdit").selectionStart = selectionStart;
-                $("sqlEdit").selectionEnd = selectionStart + autocomplete[i].length - offset;
+                var selectionStart = oAutocomplete.selectionStart;
+                var before = oAutocomplete.value.substr(0, selectionStart - offset);
+                var behind = oAutocomplete.value.substr(selectionStart, oAutocomplete.value.length);
+                oAutocomplete.value = before + autocomplete[i] + behind;
+                oAutocomplete.selectionStart = selectionStart;
+                oAutocomplete.selectionEnd = selectionStart + autocomplete[i].length - offset;
                 break;
             }
             i++;
@@ -1188,6 +1619,15 @@ function Autocomplete(evt) {
     }
 }
 
+
+/*
+=head2 selKeyword(id) 
+
+insert vales from an  <select></select> into autocomplete
+
+=cut
+*/
+
 function selKeyword(id) {
     for (var i = 0; i < $(id).options.length; i++) autocomplete.push($(id).options[i].value);
 }
@@ -1197,7 +1637,8 @@ function showSQLEditor() {
     $('popupContent1').style.left = '5%';
     $('popupContent1').style.width = '90%';
     showPopup('SqlEditor');
-    $("sqlEdit").addEventListener('keyup', Autocomplete);
+    oAutocomplete = $("sqlEdit");
+    oAutocomplete.addEventListener('keyup', Autocomplete);
     if (uno) {
         selKeyword('selKeyword');
         selKeyword('tablelist');
@@ -1211,6 +1652,14 @@ function ShowNewRow() {
     $('popupContent1').style.width = '96%';
     showPopup('ShowNewRow');
 }
+/*
+=head2 checkButton(id,parent)
+
+fake (styled) checkbox for HTML::Editor 
+
+=cut
+*/
+
 function checkButton(id,parent){
     if(parent.className == 'htmlButton' ){
          $(id).checked = "checked" 
@@ -1220,3 +1669,18 @@ function checkButton(id,parent){
        $(id).checked = "" 
     }
 }
+/*
+=head2 COPYRIGHT
+
+    Copyright (C) 2006-2015 by Hr. Dirk Lindner
+
+    perl -e'sub lze_Rocks{print/(...)/ for shift;}sub{&{"@_"}}->("lze_Rocks")'
+
+    This program is free software; you can redistribute it and/or modify it 
+    under the terms of the GNU Lesser General Public License as published by
+    the Free Software Foundation; This program is distributed in the hope 
+    that it will be useful, but WITHOUT ANY WARRANTY; without even
+    the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+    See the GNU Lesser General Public License for more details
+=cut
+*/
\ No newline at end of file
