@@ -2,13 +2,12 @@ package HTML::Editor::BBCODE;
 use strict;
 use warnings;
 use vars qw(@EXPORT @ISA $currentstring @formatString);
+use utf8;
 require Exporter;
 @HTML::Editor::BBCODE::EXPORT  = qw(BBCODE highlightCode);
 @ISA                           = qw(Exporter);
 $HTML::Editor::BBCODE::VERSION = '0.93';
 use HTML::Entities;
-
-use Syntax::Highlight::Perl ':FULL';
 $currentstring = 0;
 
 =head1 NAME
@@ -95,6 +94,10 @@ Supported BBCODE
 
      [hr]
 
+     [code=] see highlightCode
+
+     be careful function is case sensitive.
+
 
 =head2 EXPORT
 
@@ -116,6 +119,7 @@ sub BBCODE {
     @formatString  = ();
     $$string =~
       s:\[code=(Perl|Java|C\+\+|XML|Ruby|Python|PHP|JavaScript|HTML|CSS|Bash|SQL)\](.*?)\[\/code\]:highlightCode($2,$1):ges;
+    utf8::decode($$string) unless utf8::is_utf8($$string);
     $$string = encode_entities($$string);
     $$string =~ s:\[(u)\](.*?)\[/\1\]:<$1>$2</$1>:gs;
     $$string =~ s:\[(b)\](.*?)\[/\1\]:<$1>$2</$1>:gs;
@@ -189,61 +193,17 @@ SQL
 sub highlightCode {
     my $string = shift;
     my $parser = shift;
-    if ($parser eq 'Perl') {
-        my $color_Keys = {
-                          'Variable_Scalar'   => 'Variable_ # or Scalar',
-                          'Variable_Array'    => 'Variable_Array',
-                          'Variable_Hash'     => 'Variable_Hash',
-                          'Variable_Typeglob' => 'Variable_Typeglob',
-                          'Subroutine'        => 'Subroutine',
-                          'Quote'             => 'Quote',
-                          'String'            => 'String',
-                          'Comment_Normal'    => 'Comment_Normal',
-                          'Comment_POD'       => 'Comment_POD',
-                          'Bareword'          => 'Bareword',
-                          'Package'           => 'Package',
-                          'Number'            => 'Number',
-                          'Operator'          => 'Operator',
-                          'Symbol'            => 'Symbol',
-                          'Character'         => 'Character',
-                          'Directive'         => 'Directive',
-                          'Label'             => 'Label',
-                          'Line'              => 'Line',
-                         };
-        my $formatter = new Syntax::Highlight::Perl;
-        $formatter->define_substitution(
-                                        '<' => '&lt;',
-                                        '>' => '&gt;',
-                                        '&' => '&amp;',
-                                       );    # HTML escapes.
-        while (my ($type, $style) = each %{$color_Keys}) {
-            $formatter->set_format($type, [qq|<span class="$style">|, '</span>']);
-        }
-        my $perldoc_Keys = {
-                            'Builtin_Operator' => 'Builtin_Operator',
-                            'Builtin_Function' => 'Builtin_Function',
-                            'Keyword'          => 'Keyword',
-                           };
-        while (my ($type, $style) = each %{$perldoc_Keys}) {
-            $formatter->set_format(
-                $type,
-                [
-                 qq|<a onclick="window.open('http://perldoc.perl.org/search.html?q='+this.innerHTML)" class="$style">|,
-                 "</a>"
-                ]
-            );
-        }
-        $string = $formatter->format_string($string);
-    } elsif ($parser =~ /(Java|C\+\+|XML|Ruby|Python|PHP|JavaScript|HTML|CSS|Bash|SQL)/) {
+    if ($parser =~ /(Perl|C\+\+|XML|Ruby|Python|PHP|JavaScript|HTML|CSS|Bash|SQL)/) {
         $string = formatString($string, $1);
     }
     $currentstring++;
-    $formatString[$currentstring] = qq(<div style="100%;overflow:auto"><pre>$string</pre></div>);
+    $formatString[$currentstring] = $string;
     return "[Formatstring$currentstring/]";
 }
 
 sub formatString {
     my ($string, $lang) = @_;
+    my $rplc;
     eval {
         use Syntax::Highlight::Engine::Kate;
         my $hl = new Syntax::Highlight::Engine::Kate(
@@ -252,8 +212,7 @@ sub formatString {
                 "<" => "&lt;",
                 ">" => "&gt;",
                 "&" => "&amp;",
-
-                             },
+            },
             format_table => {
                         Alert        => ["<span style=\"color:#0000ff\">",       "</span>"],
                         BaseN        => ["<span style=\"color:#007f00\">",       "</span>"],
@@ -277,11 +236,10 @@ sub formatString {
                         Warning      => ["<span style=\"color:#0000ff\"><b><i>", "</b></i></span>"],
                        },
         );
-        my $rplc = $hl->highlightText($string);
-        $rplc = qq(<div style="100%;overflow:auto"><pre>$rplc</pre></div>);
-        return $rplc;
+        $rplc = $hl->highlightText($string);
     };
-    return $string;
+    return qq(<div style="100%;overflow:auto"><pre>$rplc</pre></div>);
+
 }
 
 =head1 AUTHOR
