@@ -27,7 +27,7 @@ use vars
 @MySQL::Admin::GUI::EXPORT =
   qw( ContentHeader Body ChangeDb Unique openFile action applyRights maxlength);
 @ISA                        = qw( Exporter MySQL::Admin );
-$MySQL::Admin::GUI::VERSION = '0.93';
+$MySQL::Admin::GUI::VERSION = '0.94';
 $m_bMod_perl                = ($ENV{MOD_PERL}) ? 1 : 0;
 local $^W = 0;
 our @m_processlist;
@@ -343,7 +343,7 @@ sub applyRights {
         my $r = @$t[$i]->{right} ? @$t[$i]->{right} : 0;
         if ($r > $m_nRight) {
             undef @$t[$i];
-        } elsif (defined @{@$t[$i]->{subtree}}) {
+        } elsif (ref @$t[$i]->{subtree}[0] eq "HASH" ) {
             applyRights(\@{@$t[$i]->{subtree}});
         }
     }
